import pandas as pd
import matplotlib.pyplot as plt
import numpy as np
plt.rcParams.update({"text.usetex": True}) 

#Chargement des données du fichier csv :
att=pd.read_csv("eau(3effets).csv", delimiter=';', skipfooter=8)
#(omission des 8 dernières lignes, E trop élevé pour l'imagerie med.)
E=att["E(MeV)"]*1000#conversion en keV

muEau=att["muTotal"]#coeff. massique d'atténuation

epaisseurMax=100
x=np.arange(0, epaisseurMax+0.1, 0.1)#épaisseur traversée (en mm)

#Réglages du graphique :
fig=plt.figure(figsize=(7, 9))
ax=plt.subplot(111)
ax.set_yscale("log")

plt.ylim(1e-3, 2)
plt.title("Atténuation de rayons X dans l'eau", fontsize=14)
plt.xlabel(r"épaisseur $x$ (mm)")
plt.ylabel(r"facteur d'atténuation")
plt.xlim(0, epaisseurMax)
plt.grid(which='both')

#Tracé des courbes :

Energies=[10,15, 20, 40, 80]#sélection d'énergies parmi celles existantes dans le fichier CSV

for energie in Energies:
        mu=float(att.loc[E==energie, "muTotal"])
        attenuation=np.exp(-mu*x/10)
        #Le "/10" est pour convertir x en cm dans le calcul
        plt.plot(x, attenuation, label="E=%s keV"%(energie))

plt.legend()
fig.savefig("AttenuationEauEpaisseur.png", dpi=300)
plt.show()
